@@ -78,22 +78,34 @@ namespace Spotify
         return m_isLoaded;
     }
 
-    void Album::loadCoverArt()
+    QString Album::getTypeName()
     {
-        /*Spotify::Session* session = Spotify::Session::callingSession;
-        if( session )
-            session->getAlbumCover( this );
+        //return textual form of album type
+
+        if(m_type==Spotify::Album::ALBUM)
+            return tr("Album");
+        else if(m_type==Spotify::Album::SINGLE)
+            return tr("Single");
+        else if(m_type==Spotify::Album::COMPILATION)
+            return tr("Compilation");
         else
-            qDebug() << "WARNING: Attempting to get cover art for an album without session";
-            */
+            return tr("Other");
     }
 
-    void Album::setImage( QImage image )
+    QString Album::getCategory()
     {
-        ImageContainer::setImage( image );
-        emit coverArtLoaded();
+        //Return textual form of album category
+        if(m_type==Spotify::Album::ALBUM)
+            return tr("Albums");
+        else if(m_type==Spotify::Album::SINGLE)
+            return tr("Singles");
+        else if(m_type==Spotify::Album::COMPILATION)
+            return tr("Compilations");
+        else
+            return tr("Others");
     }
 
+
     Spotify::Album* Spotify::Album::fromLink( Spotify::Link& link, QObject* parent )
     {
         if( link.isValid() && link.type() == Spotify::Link::ALBUM )
@@ -117,3 +129,22 @@ namespace Spotify
         }
     }
 } // namespace Spotify
+
+ bool albumsByTypeYearDesc(Spotify::Album* alb1, Spotify::Album* alb2)
+ {
+     //sort albums first by then, then by year (descending)
+
+     if(alb1 && alb2)
+     {
+         if(alb1->type()==alb2->type())
+         {
+             return(alb1->getYear()>alb2->getYear());
+         }
+         else
+         {
+             return(alb1->type()<alb2->type());
+         }
+     }
+
+    return false;
+ }
